@@ -2,7 +2,7 @@
 # @Author: huayuwei
 # @Date:   2021-11-22 13:28:06
 # @Last Modified by:   zhangyizhi
-# @Last Modified time: 2023-03-08 14:58:35
+# @Last Modified time: 2023-03-09 17:26:41
 
 ###########
 # imports #
@@ -49,7 +49,7 @@ class ImSpiRE_Parameters(object):
     def __init__(self):
         super(ImSpiRE_Parameters, self).__init__()
         #Basic Params#
-        self.BasicParam_OutputDir="./"
+        self.BasicParam_OutputDir="."
         self.BasicParam_OutputName="ImSpiRE"
         self.BasicParam_InputDir="./"
         self.BasicParam_InputCountFile="filtered_feature_bc_matrix.h5"  #OR count_matrix.txt
@@ -73,13 +73,13 @@ class ImSpiRE_Parameters(object):
         self.ImageParam_DAPIChannel=None
         self.ImageParam_FiducialFrameChannel=None
         ## Feature extraction#
-        self.FeatureParam_ProcessNumber=10
+        self.FeatureParam_ProcessNumber=8
         self.FeatureParam_FeatureType=0 #[0,1,2]
         self.FeatureParam_ClipLimit=0.01
         self.FeatureParam_IterCount=50
         #CellProfiler Params#
         self.CellProfilerParam_Pipeline="Cellprofiler_Pipeline_HE.cppipe"
-        self.CellProfilerParam_KernelNumber=10
+        self.CellProfilerParam_KernelNumber=8
         #OT Solver Params#
         self.OptimalTransportParam_Alpha=0.5
         self.OptimalTransportParam_Beta=0.5
@@ -527,7 +527,7 @@ class ImSpiRE_Image_Feature(object):
     run_extract_features    -- Extract texture and intensity features of subimages.
 
     """
-    def __init__(self, image_file_path, clip_limit = 0.01, n_processes = 10):
+    def __init__(self, image_file_path, clip_limit = 0.01, n_processes = 8):
         super(ImSpiRE_Image_Feature, self).__init__()
         self.image_file_path = image_file_path
         self.clip_limit = clip_limit
