@@ -2,7 +2,7 @@
 # @Author: huayuwei
 # @Date:   2021-11-25 14:37:11
 # @Last Modified by:   zhangyizhi
-# @Last Modified time: 2023-03-02 12:41:58
+# @Last Modified time: 2023-03-09 18:59:48
 
 ###########
 # imports #
@@ -172,7 +172,12 @@ def filter_patch_in_tissue_2(scale, scale_row, scale_col, pos_in_tissue, dist, p
     # os.system("backgroundremover -i compressed_image.png -a -ae 15 -o bgremover_output.png")
     
     ## mask1
-    os.system(f"backgroundremover -i {output_dir}/{output_name}/SupplementaryResults/compressed_image.png -o {output_dir}/{output_name}/SupplementaryResults/bgremover_output.png")
+    # os.system(f"backgroundremover -i {output_dir}/{output_name}/SupplementaryResults/compressed_image.png -o {output_dir}/{output_name}/SupplementaryResults/bgremover_output.png")
+    cmd=subprocess.run(f"backgroundremover -i {output_dir}/{output_name}/SupplementaryResults/compressed_image.png -o {output_dir}/{output_name}/SupplementaryResults/bgremover_output.png",shell=True,capture_output=True)
+    if cmd.returncode != 0:
+        error="Connection timed out when downloading the u2net.pth model. Please download the model from https://drive.google.com/file/d/1ao1ovG1Qtx4b7EoskHXmi2E9rp5CHLcZ/view?usp=sharing by yourself and place u2net.pth in the directory ~/.u2net/."
+        print(error)
+        sys.exit(0)
     
     rembg = cv2.imread(f"{output_dir}/{output_name}/SupplementaryResults/bgremover_output.png", cv2.IMREAD_UNCHANGED)
     if len(rembg.shape) == 3:
